==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/sr@latin.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "Dokumenta",
    "Can't create document" : "Ne mogu da kreiram dokument",
    "You don't have permission to rename this document" : "Nemate dozvolu da promenite ime ovom dokumentu",
    "Directory saved successfully." : "Direktorijum uspešno sačuvan.",
    "An error occurred while changing directory." : "Došlo je do greške prilikom promene direktorijuma.",
    "Saved" : "Sačuvano",
    "Format filter server is down or misconfigured" : "Server filtera formata je isključen ili nije dobro podešen.",
    "Conversion failed. Check log for details." : "Konverzija nije uspela. Proverite zapis za detalje.",
    "Saving..." : "Snimam...",
    "Failed to load documents." : "Neuspelo učitavanje dokumenata.",
    "No documents were found. Upload or create a document to get started!" : "Dokumenti nisu nađeni. Otpremite ili kreirajte dokument da biste započeli!",
    "No connection to server. Trying to reconnect." : "Nema veze sa serverom. Pokušavam ponovno uspostavljanje veze.",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "Napuštanje ove strane u režimu Urednika može dovesti do nesačuvanih podataka. Preporučujemo da umesto toga koristite dugme 'Zatvori'.",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "Neuspelo učitavanje dokumenta. Molimo proverite da li može biti otvoren eksternim odt uređivačem. Ovo takođe može da znači da je prekinuto njegovo deljenje ili da je obrisan nedavno.",
    "Save" : "Snimi",
    "Loading documents..." : "Učitavam dokumenta...",
    "'.' is an invalid file name." : "'.' je neispravno ime fajla.",
    "File name cannot be empty." : "Ime fajla ne može biti prazno.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Neispravno ime, '\\', '/', '<', '>', ':', '\"', '|', '?' i '*' nisu dozvoljeni.",
    "Align Left" : "Poravnaj levo",
    "Alignment" : "Poravnanje",
    "Align Right" : "Poravnaj desno",
    "Annotate" : "Pribeleži",
    "Background" : "Pozadina",
    "Bold" : "Podebljano",
    "Bottom" : "Dno",
    "Cancel" : "Otkaži",
    "Center" : "Centar",
    "Clone" : "Umnoži",
    "Clone this Style" : "Umnoži ovaj Stil",
    "Close" : "Zatvori",
    "Color" : "Boja",
    "Create" : "Napravi",
    "Decrease Indent" : "Smanji levu marginu",
    "Default Style" : "Podrazumevani Stil",
    "Delete" : "Obriši",
    "Family" : "Familija",
    "Font" : "Font",
    "Font Effects" : "Efekti Fonta",
    "Format" : "Format",
    "Increase Indent" : "Povećaj levu marginu",
    "Insert Image" : "Ubaci Sliku",
    "Invite Members" : "Pozovi Članove",
    "Italic" : "Kurziv",
    "Justified" : "Poravnato",
    "Justify" : "Poravnaj",
    "Left" : "Levo",
    "Loading" : "Učitavanje",
    "Members" : "Članovi",
    "New Name:" : "Novo ime:",
    "OK" : "Ok",
    "Open" : "Otvori",
    "Options" : "Opcije",
    "Paragraph..." : "Paragraf...",
    "Paragraph Styles" : "Stilovi Paragrafa",
    "Redo" : "Ponovi",
    "Right" : "Desno",
    "Size" : "Veličina",
    "Spacing" : "Razmak",
    "Strikethrough" : "Precrtano",
    "Style" : "Stil",
    "Text" : "Tekst",
    "Top" : "Vrh",
    "Underline" : "Podvučeno",
    "Undo" : "Vrati",
    "Unknown Author" : "Nepoznati Autor",
    "Edit" : "Uredi",
    "Share" : "Podeli",
    "guest" : "gost",
    "MS Word support (requires openOffice/libreOffice)" : "Podrška za MS Word (zahteva openOffice/libreOffice)",
    "Local" : "Lokalno",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "openOffice/libreOffice je instaliran na ovom serveru. Putanja do izvršne datoteke je data pomoću preview_libreoffice_path u config.php",
    "External" : "Spoljašnji",
    "openOffice/libreOffice is installed on external server running a format filter server" : "openOffice/libreOffice je instaliran na spoljašnjem serveru na kome radi server za filtere formata",
    "Disabled" : "Onemogućeno",
    "No MS Word support" : "Nema podrška za MS Word",
    "scheme://domain.tld[:port]" : "šema://domen.tld[:port]",
    "Server URL" : "URL servera",
    "Apply and test" : "Primeni i testiraj",
    "New document" : "Novi dokument",
    "Upload (max. %s)" : "Otpremanje  (maksimalno %s)",
    "Upload" : "Pošalji",
    "Save new documents to" : "Sačuvaj nova dokumenta u",
    "Wrong password. Please retry." : "Neispravna lozinka. Molimo, pokušajte ponovo.",
    "Password" : "Lozinka",
    "Guest %s" : "Gost %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Ova prečice je istekla ili nikad nije ni postojala. Molimo kontaktirajte osobu koja ju je delila sa Vama za detalje.",
    "Advanced feature-set" : "Napredni set mogućnosti",
    "(Unstable)" : "(Nestabilno)"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-app-documents-1%3A9.1.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/sr@latin.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "Dokumenta",
    "Can't create document" : "Ne mogu da kreiram dokument",
    "You don't have permission to rename this document" : "Nemate dozvolu da promenite ime ovom dokumentu",
    "Directory saved successfully." : "Direktorijum uspešno sačuvan.",
    "An error occurred while changing directory." : "Došlo je do greške prilikom promene direktorijuma.",
    "Saved" : "Sačuvano",
    "Format filter server is down or misconfigured" : "Server filtera formata je isključen ili nije dobro podešen.",
    "Conversion failed. Check log for details." : "Konverzija nije uspela. Proverite zapis za detalje.",
    "Saving..." : "Snimam...",
    "Failed to load documents." : "Neuspelo učitavanje dokumenata.",
    "No documents were found. Upload or create a document to get started!" : "Dokumenti nisu nađeni. Otpremite ili kreirajte dokument da biste započeli!",
    "No connection to server. Trying to reconnect." : "Nema veze sa serverom. Pokušavam ponovno uspostavljanje veze.",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "Napuštanje ove strane u režimu Urednika može dovesti do nesačuvanih podataka. Preporučujemo da umesto toga koristite dugme 'Zatvori'.",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "Neuspelo učitavanje dokumenta. Molimo proverite da li može biti otvoren eksternim odt uređivačem. Ovo takođe može da znači da je prekinuto njegovo deljenje ili da je obrisan nedavno.",
    "Save" : "Snimi",
    "Loading documents..." : "Učitavam dokumenta...",
    "'.' is an invalid file name." : "'.' je neispravno ime fajla.",
    "File name cannot be empty." : "Ime fajla ne može biti prazno.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Neispravno ime, '\\', '/', '<', '>', ':', '\"', '|', '?' i '*' nisu dozvoljeni.",
    "Align Left" : "Poravnaj levo",
    "Alignment" : "Poravnanje",
    "Align Right" : "Poravnaj desno",
    "Annotate" : "Pribeleži",
    "Background" : "Pozadina",
    "Bold" : "Podebljano",
    "Bottom" : "Dno",
    "Cancel" : "Otkaži",
    "Center" : "Centar",
    "Clone" : "Umnoži",
    "Clone this Style" : "Umnoži ovaj Stil",
    "Close" : "Zatvori",
    "Color" : "Boja",
    "Create" : "Napravi",
    "Decrease Indent" : "Smanji levu marginu",
    "Default Style" : "Podrazumevani Stil",
    "Delete" : "Obriši",
    "Family" : "Familija",
    "Font" : "Font",
    "Font Effects" : "Efekti Fonta",
    "Format" : "Format",
    "Increase Indent" : "Povećaj levu marginu",
    "Insert Image" : "Ubaci Sliku",
    "Invite Members" : "Pozovi Članove",
    "Italic" : "Kurziv",
    "Justified" : "Poravnato",
    "Justify" : "Poravnaj",
    "Left" : "Levo",
    "Loading" : "Učitavanje",
    "Members" : "Članovi",
    "New Name:" : "Novo ime:",
    "OK" : "Ok",
    "Open" : "Otvori",
    "Options" : "Opcije",
    "Paragraph..." : "Paragraf...",
    "Paragraph Styles" : "Stilovi Paragrafa",
    "Redo" : "Ponovi",
    "Right" : "Desno",
    "Size" : "Veličina",
    "Spacing" : "Razmak",
    "Strikethrough" : "Precrtano",
    "Style" : "Stil",
    "Text" : "Tekst",
    "Top" : "Vrh",
    "Underline" : "Podvučeno",
    "Undo" : "Vrati",
    "Unknown Author" : "Nepoznati Autor",
    "Shared" : "Deljeno",
    "Error" : "Greška",
    "Error while sharing" : "Greška pri deljenju",
    "Error while unsharing" : "Greška u uklanjanju deljenja",
    "Error while changing permissions" : "Greška u promeni dozvola",
    "Shared with you and the group {group} by {owner}" : "{owner} podelio sa Vama i grupom {group} ",
    "Shared with you by {owner}" : "Sa vama podelio {owner}",
    "Share" : "Podeli",
    "Share link" : "Veza deljenja",
    "The public link will expire no later than {days} days after it is created" : "Javna prečica će isteći ne kasnije od {days} dana pošto je kreirana",
    "Link" : "Prečica",
    "Password protect" : "Zaštita lozinkom",
    "Password" : "Lozinka",
    "Choose a password for the public link" : "Odredite lozinku za javnu vezu",
    "Allow editing" : "Dozvoli uređivanje",
    "Email link to person" : "Pošalji link e-mailom",
    "Send" : "Pošalji",
    "Set expiration date" : "Datum isteka",
    "Expiration" : "Isticanje",
    "Expiration date" : "Datum isteka",
    "Adding user..." : "Dodavanje korisnika...",
    "group" : "grupa",
    "remote" : "udaljeni",
    "Resharing is not allowed" : "Dalje deljenje nije dozvoljeno",
    "Shared in {item} with {user}" : "Deljeno u {item} sa {user}",
    "Unshare" : "Ne deli",
    "notify by email" : "obavesti Email-om",
    "can share" : "može da deli",
    "can edit" : "može da menja",
    "access control" : "kontrola pristupa",
    "create" : "napravi",
    "change" : "izmeni",
    "delete" : "brisanje",
    "Password protected" : "Zaštćeno lozinkom",
    "Error unsetting expiration date" : "Greška u uklanjanju datuma isteka",
    "Error setting expiration date" : "Greška u postavljanju datuma isteka",
    "Sending ..." : "Slanje...",
    "Email sent" : "Email poslat",
    "Warning" : "Upozorenje",
    "Edit" : "Uredi",
    "guest" : "gost",
    "MS Word support (requires openOffice/libreOffice)" : "Podrška za MS Word (zahteva openOffice/libreOffice)",
    "Local" : "Lokalno",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "openOffice/libreOffice je instaliran na ovom serveru. Putanja do izvršne datoteke je data pomoću preview_libreoffice_path u config.php",
    "External" : "Spoljašnji",
    "openOffice/libreOffice is installed on external server running a format filter server" : "openOffice/libreOffice je instaliran na spoljašnjem serveru na kome radi server za filtere formata",
    "Disabled" : "Onemogućeno",
    "No MS Word support" : "Nema podrška za MS Word",
    "scheme://domain.tld[:port]" : "šema://domen.tld[:port]",
    "Server URL" : "URL servera",
    "Apply and test" : "Primeni i testiraj",
    "New document" : "Novi dokument",
    "Upload (max. %s)" : "Otpremanje  (maksimalno %s)",
    "Upload" : "Pošalji",
    "Save new documents to" : "Sačuvaj nova dokumenta u",
    "Wrong password. Please retry." : "Neispravna lozinka. Molimo, pokušajte ponovo.",
    "Guest %s" : "Gost %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Ova prečice je istekla ili nikad nije ni postojala. Molimo kontaktirajte osobu koja ju je delila sa Vama za detalje.",
    "Advanced feature-set" : "Napredni set mogućnosti",
    "(Unstable)" : "(Nestabilno)"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
